@@ -1,21 +1,13 @@
 import numpy as np
 import pandas as pd
 import pytest
-import visions
-from pandas._testing import assert_series_equal
+from pandas.testing import assert_series_equal
 from visions import StandardSet
 
 from compressio.compress import compress_func
 from compressio.type_compressor import DefaultCompressor
 
-if hasattr(visions, "BoolDtype"):
-    from visions import BoolDtype
-
-    bool_type = BoolDtype
-elif hasattr(pd, "BooleanDtype"):
-    bool_type = pd.BooleanDtype
-else:
-    raise RuntimeError("No boolean Dtype found. Please update visions/pandas")
+bool_dtype = "boolean" if int(pd.__version__.split(".")[0]) >= 1 else "Bool"
 
 
 @pytest.mark.parametrize(
@@ -24,13 +16,13 @@ else:
         (
             pd.Series([10.0, 100.0, np.iinfo(np.int16).max * 1.0], dtype=np.float64),
             np.float64,
-            np.int16,
+            "int16",
         ),
-        (pd.Series([np.nan, 1], dtype=np.float64), np.float64, pd.Int8Dtype),
+        (pd.Series([np.nan, 1], dtype=np.float64), np.float64, "Int8"),
         (
             pd.Series([True, False, None, None, None, None, True, False] * 1000),
             np.object,
-            bool_type,
+            bool_dtype,
         ),
     ],
 )
@@ -42,8 +34,7 @@ def test_compress_series(series, before, expected):
         compressor=DefaultCompressor(),
         with_inference=True,
     )
-    assert compressed_series.dtype == expected or isinstance(
-        compressed_series.dtype, expected
-    )
+
+    assert str(compressed_series.dtype) == expected
 
     assert_series_equal(series, compressed_series, check_dtype=False)
